abacusai.feature_drift_record — AbacusAI documentation

# `abacusai.feature_drift_record`

## Module Contents

### Classes

`FeatureDriftRecord` | Value of each type of drift

class abacusai.feature_drift_record.FeatureDriftRecord(client, name=None, distance=None, jsDistance=None, wsDistance=None, ksStatistic=None, psi=None, csi=None, chiSquare=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Value of each type of drift

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – Name of feature.

    - distance (float) – Symmetric sum of KL divergences between the training distribution and the range of values in the specified window.

    - jsDistance (float) – JS divergence between the training distribution and the range of values in the specified window.

    - wsDistance (float) – Wasserstein distance between the training distribution and the range of values in the specified window.

    - ksStatistic (float) – Kolmogorov-Smirnov statistic computed between the training distribution and the range of values in the specified window.

    - psi (float) – Population stability index computed between the training distribution and the range of values in the specified window.

    - csi (float) – Characteristic Stability Index computed between the training distribution and the range of values in the specified window.

    - chiSquare (float) – Chi-square statistic computed between the training distribution and the range of values in the specified window.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict